******
v0.2.0
******

:Date: December 24, 2024

The changes since Manim DSA release v0.1.0 are listed below.

New Features
------------

- Added documentation for the whole library.
- Bug fixes.
- Renamed the style classes to follow the naming convention.